metric

package
v1.4.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package metric provides with Counter and Gauge interfaces. See /cmetric for an implementation using shared memory to cmetrics library.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Counter

type Counter interface {
	Add(delta float64, labelValues ...string)
}

Counter describes a metric that accumulates values monotonically.

type Gauge

type Gauge interface {
	Add(delta float64, labelValues ...string)
	Set(value float64, labelValues ...string)
}

Gauge describes a metric that takes specific values over time.

Directories

Path Synopsis

Jump to