Documentation
¶
Index ¶
- func FLBPluginExit() int
- func FLBPluginFlush(data unsafe.Pointer, clength C.int, ctag *C.char) int
- func FLBPluginInit(ptr unsafe.Pointer) int
- func FLBPluginInputCallback(data *unsafe.Pointer, csize *C.size_t) int
- func FLBPluginRegister(def unsafe.Pointer) int
- func RegisterInput(name, desc string, in InputPlugin)
- func RegisterOutput(name, desc string, out OutputPlugin)
- type ConfigLoader
- type InputPlugin
- type Message
- type OutputPlugin
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FLBPluginExit ¶
func FLBPluginExit() int
func FLBPluginInit ¶
func FLBPluginInputCallback ¶
func FLBPluginRegister ¶
func RegisterInput ¶
func RegisterInput(name, desc string, in InputPlugin)
RegisterInput plugin. This function must be called only once per file.
func RegisterOutput ¶
func RegisterOutput(name, desc string, out OutputPlugin)
RegisterOutput plugin. This function must be called only once per file.
Types ¶
type ConfigLoader ¶
type InputPlugin ¶
type Message ¶
type OutputPlugin ¶
Click to show internal directories.
Click to hide internal directories.